@@ -1,10 +1,10 @@
 # !/usr/bin/env python
 #  -*- coding: UTF-8 -*-
 
-__version__ = "0.1.3"  # LATEST? =>  https://pypi.org/project/lookml-helper/
-__copyright__ = "CopyRight (C) 2021 by Donald Duck"
+__version__ = "0.2"  # LATEST? =>  https://pypi.org/project/lookml-helper/
+__copyright__ = "CopyRight (C) 2022 by Michele Pasin and Joerg Sixt"
 __license__ = "MIT"
-__author__ = "Donald Duck"
+__author__ = "Michele Pasin and Joerg Sixt"
 __author_email__ = ""
 
 USAGE = "lookmlhelper [options]"
