@@ -31,29 +31,30 @@ def create_nested_dimension(field, add_links_dimensions = True, verbose=False):
 
   if field.modus == "ARRAY":
     dimension_lml = f"""
-    {make_header(field, "Links-dimensions for array", True)}
-    dimension: {field.nested_dimension_name} {{
-      hidden: yes
-      description: "{field.description}"
-      sql: ${{TABLE}}.{field.unnested_sql} ;;
-    }}"""
+  {make_header(field, "Links-dimensions for array", True)}
+  dimension: {field.nested_dimension_name} {{
+    hidden: yes
+    description: "{field.description}"
+    sql: ${{TABLE}}.{field.unnested_sql} ;;
+  }}
+    """
 
     if add_links_dimensions:
       dimension_lml = dimension_lml + f"""
-      dimension: links_{field.nested_dimension_name} {{
-        type: number
-        hidden:  no
-        label: "Nr of {field.label_plural}"
-        description: "Non-unique Nr of {field.label_plural}: {field.description}"
-        group_label: "Links count"
-        sql: ARRAY_LENGTH(${{{field.nested_dimension_name}}}) ;;
-      }}
-      dimension: has_{field.nested_dimension_name} {{
-        description: "Yes if {get_global_configuration()['pretty_looker_name']} has any {field.label_plural}"
-        type: yesno
-        group_label: "Links check"
-        sql: ${{links_{field.nested_dimension_name}}} > 0 ;;
-      }}
+  dimension: links_{field.nested_dimension_name} {{
+    type: number
+    hidden:  no
+    label: "Nr of {field.label_plural}"
+    description: "Non-unique Nr of {field.label_plural}: {field.description}"
+    group_label: "Links count"
+    sql: ARRAY_LENGTH(${{{field.nested_dimension_name}}}) ;;
+  }}
+  dimension: has_{field.nested_dimension_name} {{
+    description: "Yes if {get_global_configuration()['pretty_looker_name']} has any {field.label_plural}"
+    type: yesno
+    group_label: "Links check"
+    sql: ${{links_{field.nested_dimension_name}}} > 0 ;;
+  }}
       """
 
     if field.nested_dimension_name == "active_years":
@@ -92,41 +93,42 @@ def create_all_raw_array_dimensions(looker_metadata, verbose=False):
   if verbose:
     printDebug("Generating joins for the top level ", len(top_level_array_struct_fields), " arrays and struct found in the table")
     printDebug(top_level_array_struct_fields)
-  return "".join(list(top_level_array_struct_fields.apply(create_nested_dimension, axis=1)))
+  if len(top_level_array_struct_fields)> 0:
+    return "".join(list(top_level_array_struct_fields.apply(create_nested_dimension, axis=1)))
+  else:
+    return ""
 
 
 
 def write_raw_array_view(output_path, looker_metadata):
 
-    raw_array_view_lml = f"""
-    ##############
-    ## {get_global_configuration()['capital_looker_name']}: BASE VIEWS - GBQ ARRAY FIELDS
-    #
-    # - represents GBQ fields 1:1
-    # - array field is normally a hidden dimension (used in nested JOINs)
-    # - extra dimensions for each array: links count
-    # - optional dimensions for each array: HasValue Yes/no (shortcut for quick filtering)
-    #
-    ##############
+    all_raw_array_dimensions = create_all_raw_array_dimensions(looker_metadata)
 
+    if all_raw_array_dimensions != "":
+      raw_array_view_lml = f"""
+##############
+## {get_global_configuration()['capital_looker_name']}: BASE VIEWS - GBQ ARRAY FIELDS
+#
+# - represents GBQ fields 1:1
+# - array field is normally a hidden dimension (used in nested JOINs)
+# - extra dimensions for each array: links count
+# - optional dimensions for each array: HasValue Yes/no (shortcut for quick filtering)
+#
+##############
 
+view: arrays_{get_global_configuration()['looker_name']} {{
 
+  sql_table_name: `{get_global_configuration()['gbq_resource_name']}.{get_global_configuration()['gbq_datset_name']}.{get_global_configuration()['gbq_table_name']}`;;
 
+{all_raw_array_dimensions}
 
-    view: arrays_{get_global_configuration()['looker_name']} {{
+}}
+      """
 
-    sql_table_name: `dimensions-ai.data_analytics.{get_global_configuration()['looker_name']}`
-    ;;
-
-    {create_all_raw_array_dimensions(looker_metadata)}
-
-    }}
-    """
-
-    # printDebug(raw_array_view_lml)
-    f = open(output_path+"/views/raw/array."+get_global_configuration()['looker_name']+".view.lkml", "w")
-    f.write(raw_array_view_lml)
-    f.close()
+      # printDebug(raw_array_view_lml)
+      f = open(output_path+"/views/raw/array."+get_global_configuration()['looker_name']+".view.lkml", "w")
+      f.write(raw_array_view_lml)
+      f.close()
 
 
 
@@ -147,12 +149,14 @@ def create_unnested_dimension(field):
                                       not field.data_type.startswith('ARRAY<STRUCT<'))
 
   #Default values of some sections
-  dimension_type = "dimension"
-  dimension_name = field.unnested_dimension_name
-  header = ""
-  extras = ""
-  group_label    = field.group_label
-  label = field.label
+  dimension_type    = "dimension"
+  dimension_name    = field.unnested_dimension_name
+  header            = ""
+  extras            = ""
+  group_label       = field.group_label
+  label             = field.label
+  standard_sql      = True
+
 
   if field.modus == "FIELD":
     data_type = field.data_type   
@@ -165,8 +169,8 @@ def create_unnested_dimension(field):
     looker_type = "number"
   elif data_type == "BOOL":
     looker_type = "yesno"
-  elif (data_type in ["DATE", "TIMESTAMP", "TIME", "DATETIME"]) or field.column_name.endswith("date") or field.column_name.startswith("date_") :
-    looker_type = "time"
+  elif (data_type in ["DATE", "TIMESTAMP", "DATETIME"]) or field.column_name.endswith("date") or field.column_name.startswith("date_") :
+    looker_type = "date_time"
     dimension_type = "dimension_group"
     extras = """
     timeframes: [
@@ -186,65 +190,88 @@ def create_unnested_dimension(field):
       group_label= "Dates"
     if data_type == "STRING":
       sql = f"CAST({sql} AS DATE)"
- 
+  elif data_type == "TIME":
+    looker_type = "time"
+    dimension_type = "dimension_group"
+    extras = """
+    timeframes: [
+      raw,
+      hour,
+      minute,
+      second    
+    ]
+    convert_tz: no
+    datatype: time"""
+    group_label= "Times"
   elif data_type == "STRING":
     looker_type = "string"
     if "country" in dimension_name or "countries" in dimension_name or "jurisdiction" in dimension_name:
       extras = extras+"""
     map_layer_name: countries"""
+  elif data_type == "JSON":
+    looker_type = "string"
+    sql = f"TO_JSON_STRING({sql}) # £££: GBQ TYPE 'JSON' NOT PROPERLY SUPPORTED. CODING SIMPLY CONVERTS JSON TO STRING"
+  elif data_type == "BYTES":
+    looker_type = "string"
+    sql = f"SAFE_CONVERT_BYTES_TO_STRING({sql})  # £££: GBQ TYPE 'BYTES' NOT PROPERLY SUPPORTED. CODING SIMPLY TRIES TO CONVERT TO STRING AS BEST AS POSSIBLE"
+  elif data_type == "GEOGRAPHY":
+    looker_type = "location"
+    standard_sql = False
+    sql = f"""# £££: GBQ TYPE 'GEOGRAPHY' NOT PROPERLY SUPPORTED. CODING WORKS WELL ONLY IF THERE ARE ONLY NULL and 1-POINT VALUES
+    sql_longitude: SAFE.ST_X({sql});;
+    sql_latitude:  SAFE.ST_Y({sql});;"""
   else:
-    printDebug("Unknown type:", data_type)
-    printDebug(field)
-    printDebug(f"""
-    #
-    # ££££££££
-    # Cannot generate code for {field.field_path} because of
-    # type {data_type} 
-    """)
-    assert 1 == 2
+    printDebug("Unknown GBQ data type", data_type, " found for ", field.field_path, "!")
+    looker_type = "string"
+    sql = f"CAST({sql} TO STRING)  # £££: GBQ TYPE '{data_type}' NOT SUPPORTED. CODING ONLY TRIES TO CAST TO STRING WHICH MAY FAIL"
 
   if field.field_path == "id":
     group_label= "Identifiers"
     extras = f"""
     primary_key: yes"""
-    label = " Dimensions ID" # --- LEADING SPACE ---
+    label = " ID" # --- LEADING SPACE ---
+    if looker_type == "number":
+      extras = extras +"""
+    value_format: "0" """
   
   if dimension_name.endswith("_id"):
     group_label= "Identifiers"
+    if looker_type == "number":
+      extras = extras +"""
+    value_format: "0" """
 
   if dimension_name.endswith("year") and looker_type=="number":
     group_label = "Dates"
     label = label +" (number)"
-    extras= """
+    extras= extras + """
     value_format: "0000" """
 
   # For some attributes we may need special casts see at the beginning
   sql = get_global_configuration()['special_casts'].get(dimension_name, sql)
 
+  if standard_sql:
+    sql = f"""sql: {sql};;"""
+
   dimension_lml =f"""{make_header(field, "", False)}
   {dimension_type}: {dimension_name} {{
     type:         {looker_type}
     label:        "{label}"
     description:  "{field.description}"{extras}
     group_label:  "{group_label}"
-    sql: {sql};;{get_link(field)}
+    {sql}{get_global_configuration()['link_func'](field)}
   }}
   """
 
-  # Add a full name for good measure 
+  # Add a full name
   if dimension_name == "last_name":
     dimension_lml = dimension_lml + f"""
   dimension: full_name {{
     type:         string
     label:        "Full Name"
-    group_label:  "{group_label}"  #£££ CHECK THIS!
+    group_label:  "{group_label}"  #£££ EDIT IF NEEDED
     sql: COALESCE(CONCAT(${{first_name}}, ' ', ${{last_name}}), ${{last_name}}, ${{first_name}});;
-    link: {{
-      label: "Dimensions"
-      url: "https://app.dimensions.ai/details/entities/publication/author/{{{{ researcher_id._value }}}}" #£££ check if correct value
-      icon_url: "https://www.dimensions.ai/wp-content/plugins/dimensions-blocks/assets/images/dimensions-hexagon-gradient.png"
-    }}
-  }}"""
+  }}
+    """
 
   return dimension_lml
   
@@ -256,34 +283,37 @@ def create_all_raw_fields_dimensions(looker_metadata, verbose=False):
   if verbose:
     printDebug("Generating joins for the top level ", len(fields), " simple fields found in the table")
     printDebug(fields)
-  return "".join(list(fields.apply(create_unnested_dimension, axis=1)))
+  if len(fields) > 0:
+    return "".join(list(fields.apply(create_unnested_dimension, axis=1)))
+  else:
+    return ""
 
 
 
 def write_raw_fields_view(output_path, looker_metadata):
-
-    raw_fields_lml = f"""
-    ##############
-    ## {get_global_configuration()['capital_looker_name']}: BASE VIEWS - MISC FIELDS
-    #
-    # - represents GBQ fields 1:1
-    #
-    # https://docs.dimensions.ai/bigquery/datasource-{get_global_configuration()['looker_name']}.html
-    ##############
+    all_raw_fields_dimensions = create_all_raw_fields_dimensions(looker_metadata)
+    if all_raw_fields_dimensions:
+      raw_fields_lml = f"""
+##############
+## {get_global_configuration()['capital_looker_name']}: BASE VIEWS - MISC FIELDS
+#
+# - represents GBQ fields 1:1
+#
+# https://docs.dimensions.ai/bigquery/datasource-{get_global_configuration()['looker_name']}.html
+##############
 
 
-    view: fields_{get_global_configuration()['looker_name']} {{
+view: fields_{get_global_configuration()['looker_name']} {{
 
-    sql_table_name: `dimensions-ai.data_analytics.{get_global_configuration()['looker_name']}`
-    ;;
+  sql_table_name: `{get_global_configuration()['gbq_resource_name']}.{get_global_configuration()['gbq_datset_name']}.{get_global_configuration()['gbq_table_name']}`;;
 
-    {create_all_raw_fields_dimensions(looker_metadata)}
+{all_raw_fields_dimensions}
 
-    }}
-    """
-    f = open(output_path+"/views/raw/fields."+get_global_configuration()['looker_name']+".view.lkml", "w")
-    f.write(raw_fields_lml)
-    f.close()
+}}
+      """
+      f = open(output_path+"/views/raw/fields."+get_global_configuration()['looker_name']+".view.lkml", "w")
+      f.write(raw_fields_lml)
+      f.close()
 
 
 
@@ -330,35 +360,35 @@ def create_array_unnested_view(field, looker_metadata):
 
   if field.field_path in get_global_configuration()['fields_w_offset_joins'] :
     dimensions_lml = f"""
-    dimension: {field.field_path}_key {{
-      type: string
-      hidden: yes
-      primary_key: yes
+  dimension: {field.field_path}_key {{
+    type: string
+    hidden: yes
+    primary_key: yes
 
-      # TIP: in the explore join, an OFFSET is created and given the alias authors_offset
-      # https://cloud.google.com/bigquery/docs/reference/standard-sql/query-syntax#unnest_operator
-      sql: CONCAT({field.unnested_sql}_offset, ${{{get_global_configuration()['looker_name']}.id}}) ;;
-    }}"""+dimensions_lml
+    # TIP: in the explore join, an OFFSET is created and given the alias authors_offset
+    # https://cloud.google.com/bigquery/docs/reference/standard-sql/query-syntax#unnest_operator
+    sql: CONCAT({field.unnested_sql}_offset, ${{{get_global_configuration()['looker_name']}.id}}) ;;
+  }}"""+dimensions_lml
 
   if field.field_path == "concepts":
     dimensions_lml = dimensions_lml + """
-    dimension: is_0_5_plus {
-      description: "Yes if concept has a relevance score major than 0.5"
-      label: "Has Relevance 0.5+"
-      hidden: no
-      type: yesno
-      group_label: "Concepts"
-      sql: ${relevance} > 0.5 ;;
-    }
+  dimension: is_0_5_plus {
+    description: "Yes if concept has a relevance score major than 0.5"
+    label: "Has Relevance 0.5+"
+    hidden: no
+    type: yesno
+    group_label: "Concepts"
+    sql: ${relevance} > 0.5 ;;
+  }
 
-    dimension: is_0_6_plus {
-      description: "Yes if concept has a relevance score major than 0.6"
-      label: "Has Relevance 0.6+"
-      hidden: no
-      type: yesno
-      group_label: "Concepts"
-      sql: ${relevance} > 0.6 ;;
-    }
+  dimension: is_0_6_plus {
+    description: "Yes if concept has a relevance score major than 0.6"
+    label: "Has Relevance 0.6+"
+    hidden: no
+    type: yesno
+    group_label: "Concepts"
+    sql: ${relevance} > 0.6 ;;
+  }
     """
 
   view_lml = f"""
@@ -375,27 +405,34 @@ def create_all_array_unnested_views(looker_metadata, verbose=False):
   if verbose:
     printDebug("Generating joins for the not top level ", len(fields), " arrays  found in the table")
     printDebug(fields)
-  return "".join(list(fields.apply(create_array_unnested_view, axis=1, looker_metadata=looker_metadata)))
+  if len(fields) > 0:
+    return "".join(list(fields.apply(create_array_unnested_view, axis=1, looker_metadata=looker_metadata)))
+  else:
+    return ""
 
 
 def write_unested_array_view(output_path, looker_metadata):
 
-    unnested_array_nested_lml = f"""
-    ##############
-    ## {get_global_configuration()['capital_looker_name']}: NESTED FIELDS VIEWS - MISCELLANEOUS
-    #
-    # - represents GBQ nested fields by adding a view for each of them
-    #
-    # https://docs.dimensions.ai/bigquery/datasource-{get_global_configuration()['looker_name']}.html
-    ##############
+  all_array_unnested_views = create_all_array_unnested_views(looker_metadata)
+  if all_array_unnested_views:
+      unnested_array_nested_lml = f"""
+##############
+## {get_global_configuration()['capital_looker_name']}: NESTED FIELDS VIEWS - MISCELLANEOUS
+#
+# - represents GBQ nested fields by adding a view for each of them
+#
+# https://docs.dimensions.ai/bigquery/datasource-{get_global_configuration()['looker_name']}.html
+##############
 
-    include: "{get_global_configuration()['looker_parent_folder']}/{get_global_configuration()['looker_name']}/views/base.view.lkml"
-    {create_all_array_unnested_views(looker_metadata)}
-    """
+include: "../base.view"
 
-    f = open(output_path+"/views/unnested/array.nested.view.lkml", "w")
-    f.write(unnested_array_nested_lml)
-    f.close()
+
+{all_array_unnested_views}
+      """
+
+      f = open(output_path+"/views/unnested/array.nested.view.lkml", "w")
+      f.write(unnested_array_nested_lml)
+      f.close()
 
 
 
@@ -428,14 +465,18 @@ def create_base_field_measure(field):
   return dimension_ml
 
 def create_all_base_field_measures(looker_metadata, verbose=False):
-  fields = looker_metadata[looker_metadata.data_type.isin(['INT64', 'FLOAT64', "BOOL"])&
-          (~looker_metadata.field_path.str.contains("year")) &
-          (looker_metadata.field_path != "concepts.relevance") &
+  fields = looker_metadata[looker_metadata.data_type.isin(['INT64', 'FLOAT64', "BOOL"])& # avg & sums are only possible for these types
+          (~looker_metadata.field_path.str.contains("year")) & # averages and sums for attributes that are numerical but include years or ids don't make sense
+          (looker_metadata.field_path != "id") & 
+          (~looker_metadata.field_path.str.endswith("_id")) & 
           (looker_metadata.unnested_view_name == get_global_configuration()['looker_name'])]
   if verbose:
     printDebug("Generating joins for the  top level ", len(fields), " fields  found in the table")
     # display(fields)
-  return "".join(list(fields.apply(create_base_field_measure, axis=1)))
+  if len(fields) > 0:
+    return "".join(list(fields.apply(create_base_field_measure, axis=1)))
+  else:
+    return ""
 
 
 #
@@ -477,7 +518,8 @@ def create_array_measure(field):
     group_label: "{field.group_label}"
     sql: ${{links_{field.nested_dimension_name}}} ;;
     drill_fields: [detail*]
-  }}"""
+  }}
+    """
   else:
     measure_lml = ""
 
@@ -505,86 +547,97 @@ def create_all_link_measures(looker_metadata, verbose=False):
   if verbose:
     printDebug("Generating joins for the top level ", len(fields), " arrays  found in the table")
     # display(fields)
-  return "".join(list(fields.apply(create_array_measure, axis=1)))
+  if len(fields)>0:
+    return "".join(list(fields.apply(create_array_measure, axis=1)))
+  else:
+    return ""
 
 
 def write_base_view(output_path, looker_metadata):
+    all_base_field_measures = create_all_base_field_measures(looker_metadata)
+    if all_base_field_measures:
+      all_base_field_measures =f"""
 
+  #######################
+  #  MEASURES FOR NUMERIC FIELDS
+  #
+  {all_base_field_measures}
+      """
+
+    all_link_measures = create_all_link_measures(looker_metadata)
+    if all_link_measures:
+      all_link_measures = f"""
+
+  #######################
+  #  MEASURES FOR ARRAYS/LINKS
+  #
+  {all_link_measures}
+      """
+      # If there are any arrays we need also include the array view
+      include_array_view = f"arrays_{get_global_configuration()['looker_name']}, "
+    else:
+      include_array_view = ""
 
     base_view_lml = f"""
-    ##############
-    ## {get_global_configuration()['capital_looker_name']} BASE VIEW
-    #
-    # - raw fields as they appear in GBQ
-    # - basic measures
-    # - no 'unnested' views dependencies
-    #
-    ##############
-
-    include: "{get_global_configuration()['looker_parent_folder']}/{get_global_configuration()['looker_name']}/views/raw/*.view"
+##############
+## {get_global_configuration()['capital_looker_name']} BASE VIEW
+#
+# - raw fields as they appear in GBQ
+# - basic measures
+# - no 'unnested' views dependencies
+#
+##############
 
 
-    view: {get_global_configuration()['looker_name']}_base {{
-
-    extends: [arrays_{get_global_configuration()['looker_name']}, fields_{get_global_configuration()['looker_name']}]
-    sql_table_name: `dimensions-ai.data_analytics.{get_global_configuration()['looker_name']}` ;;
-
-    label: "{get_global_configuration()['pretty_looker_name']}"
+include: "raw/*.view"
 
 
-    ##############
-    ##############
-    ##
-    # FIELD SETS FOR DRILLING
-    ##
-    ##############
-    ##############
+view: {get_global_configuration()['looker_name']}_base {{
 
+  extends: [{include_array_view}fields_{get_global_configuration()['looker_name']}]
+  sql_table_name: `{get_global_configuration()['gbq_resource_name']}.{get_global_configuration()['gbq_datset_name']}.{get_global_configuration()['gbq_table_name']}` ;;
 
+  label: "{get_global_configuration()['pretty_looker_name']}"
 
-    # default
-    drill_fields: [id]
+  ##############
+  ##############
+  ##
+  # FIELD SETS FOR DRILLING
+  ##
+  ##############
+  ##############
 
+  # £££: EDIT DEFAULT & DETAILS DRILL FIELDS 
+  drill_fields: [id]
 
-    # ----- Sets of fields for drilling in ------
-    set: detail {{
-        fields: [{
-            ", ".join(looker_metadata[
-            (looker_metadata.unnested_view_name == get_global_configuration()['looker_name']) & 
-            (looker_metadata.modus == "FIELD") ].unnested_dimension_name.head(4))
-            }]
-    }}
+  set: detail {{
+      fields: [{
+          ", ".join(looker_metadata[
+          (looker_metadata.unnested_view_name == get_global_configuration()['looker_name']) & 
+          (looker_metadata.modus == "FIELD") ].unnested_dimension_name.head(4))
+          }]
+  }}
 
+  ##############
+  ##############
+  ##
+  # MEASURES derived from RAW fields
+  ##
+  ##############
+  ##############
 
+  measure: count {{
+      type: count
+      label: "Unique {get_global_configuration()['pretty_looker_name']}"
+      group_label: " {get_global_configuration()['pretty_looker_name']}"
+      drill_fields: [detail*]
+  }}
 
-    ##############
-    ##############
-    ##
-    # MEASURES derived from RAW fields
-    ##
-    ##############
-    ##############
+  {all_base_field_measures}
 
-    measure: count {{
-        type: count
-        label: "Unique {get_global_configuration()['pretty_looker_name']}"
-        group_label: " {get_global_configuration()['pretty_looker_name']}"
-        drill_fields: [detail*]
-    }}
-    
+  {all_link_measures}
 
-    #######################
-    #  MEASURES FOR NUMERIC FIELDS
-    #
-    {create_all_base_field_measures(looker_metadata)}
-
-
-    #######################
-    #  MEASURES FOR ARRAYS/LINKS
-    #
-    {create_all_link_measures(looker_metadata)}
-
-    }}
+}}
     """
 
     f = open(output_path+"/views/base.view.lkml", "w")
@@ -621,46 +674,51 @@ def create_all_unnested_measures(looker_metadata, verbose=False):
   if verbose:
     printDebug("Generating joins for the  ", len(fields), " fields  found in the table")
     # display(fields)
-  return "".join(list(fields.apply(create_unnested_measure, axis=1)))
+  if len(fields) > 0:
+    return "".join(list(fields.apply(create_unnested_measure, axis=1)))
+  else:
+    return ""
 
 
 
 def write_unnested_view(output_path, looker_metadata):
 
-    unnested_views_lml = f"""
-    ##############
-    ## {get_global_configuration()['capital_looker_name']}: UNNESTED VIEW
-    #
-    # - extend BASE by adding unnesting logic
-    # - additional measures
-    #
-    # NOTE: when importing this view into an Explore, you need all
-    # the unnesting JOINs for the symbols to resolve
-    ##############
+    all_unnested_measures = create_all_unnested_measures(looker_metadata)
+    if all_unnested_measures:
+      unnested_views_lml = f"""
+##############
+## {get_global_configuration()['capital_looker_name']}: UNNESTED VIEW
+#
+# - extend BASE by adding unnesting logic
+# - additional measures
+#
+# NOTE: when importing this view into an Explore, you need all
+# the unnesting JOINs for the symbols to resolve
+##############
 
-    include: "{get_global_configuration()['looker_parent_folder']}/{get_global_configuration()['looker_name']}/views/base.view"
-    include: "{get_global_configuration()['looker_parent_folder']}/{get_global_configuration()['looker_name']}/views/unnested/*.view"
+include: "base.view"
+include: "unnested/*.view"
 
 
-    view: {get_global_configuration()['looker_name']}_unnested {{
+view: {get_global_configuration()['looker_name']}_unnested {{
 
-    extends: [{get_global_configuration()['looker_name']}_base]
+  extends: [{get_global_configuration()['looker_name']}_base]
 
 
-    ##############
-    ##############
-    ##
-    # MEASURES THAT REQUIRE UNNESTED DATA
-    ##
-    ##############
-    ##############
+  ##############
+  ##############
+  ##
+  # MEASURES THAT REQUIRE UNNESTED DATA
+  ##
+  ##############
+  ##############
 
-    {create_all_unnested_measures(looker_metadata)}
+  {all_unnested_measures}
 
-    }}
-    """
+}}
+      """
 
 
-    f = open(output_path+"/views/unnested.view.lkml", "w")
-    f.write(unnested_views_lml)
-    f.close()
\ No newline at end of file
+      f = open(output_path+"/views/unnested.view.lkml", "w")
+      f.write(unnested_views_lml)
+      f.close()
\ No newline at end of file
